Update to libsrtp-1.5.2 and take maintainer, ok dhill

This commit is contained in:
sthen 2015-04-25 23:40:48 +00:00
parent 9c67f5691d
commit 40daa71433
6 changed files with 40 additions and 32 deletions

View File

@ -1,23 +1,23 @@
# $OpenBSD: Makefile,v 1.5 2014/10/22 09:44:07 jasper Exp $
# $OpenBSD: Makefile,v 1.6 2015/04/25 23:40:48 sthen Exp $
COMMENT= secure RTP library
DISTNAME= srtp-1.4.4
REVISION= 1
V= 1.5.2
DISTNAME= srtp-$V
DISTFILES= ${DISTNAME}{v$V}${EXTRACT_SUFX}
PKGNAME= lib${DISTNAME}
CATEGORIES= security telephony
EXTRACT_SUFX= .tgz
MAINTAINER= David Hill <dhill@mindcry.org>
MAINTAINER= Stuart Henderson <sthen@openbsd.org>
HOMEPAGE= http://srtp.sourceforge.net/srtp.html
# BSD
PERMIT_PACKAGE_CDROM= Yes
MASTER_SITES= ${MASTER_SITE_SOURCEFORGE:=srtp/}
MASTER_SITES= https://github.com/cisco/libsrtp/archive/
WRKDIST= ${WRKDIR}/srtp
WRKDIST= ${WRKDIR}/${PKGNAME}
CONFIGURE_STYLE= gnu
CFLAGS+= -fPIC

View File

@ -1,2 +1,2 @@
SHA256 (srtp-1.4.4.tgz) = 2cLLsclRcu0tyWPv8NbOEHIybcgcsd04QU6fDkMK8xQ=
SIZE (srtp-1.4.4.tgz) = 502890
SHA256 (srtp-1.5.2.tar.gz) = huHv41M5fAdR9r3XCXlBQ70bdklEEoYPFv8rbZwwTto=
SIZE (srtp-1.5.2.tar.gz) = 1690272

View File

@ -0,0 +1,13 @@
$OpenBSD: patch-test_rtp_decoder_c,v 1.1 2015/04/25 23:40:49 sthen Exp $
--- test/rtp_decoder.c.orig Sat Apr 25 10:29:19 2015
+++ test/rtp_decoder.c Sat Apr 25 10:31:44 2015
@@ -466,7 +466,8 @@ rtp_decoder_handle_pkt(u_char *arg, const struct pcap_
dcdr->frame_nr++;
if (dcdr->start_tv.tv_sec == 0 && dcdr->start_tv.tv_sec == 0) {
- dcdr->start_tv = hdr->ts;
+ dcdr->start_tv.tv_sec = hdr->ts.tv_sec;
+ dcdr->start_tv.tv_usec = hdr->ts.tv_usec;
}
if (hdr->caplen < dcdr->rtp_offset) {

View File

@ -1,18 +1,9 @@
$OpenBSD: patch-test_rtpw_test_sh,v 1.1 2012/01/06 00:45:06 sthen Exp $
--- test/rtpw_test.sh.orig Tue Jun 13 16:17:57 2006
+++ test/rtpw_test.sh Thu Jan 5 23:35:39 2012
@@ -4,7 +4,7 @@
#
# tests the rtpw sender and receiver functions
$OpenBSD: patch-test_rtpw_test_sh,v 1.2 2015/04/25 23:40:49 sthen Exp $
--- test/srtp_driver.c.orig Wed May 9 17:29:13 2012
+++ test/srtp_driver.c Wed May 9 17:43:31 2012
@@ -314,7 +314,7 @@ main (int argc, char *argv[]) {
--- test/srtp_driver.c.orig Mon Oct 13 15:35:33 2014
+++ test/srtp_driver.c Mon Nov 10 20:34:33 2014
@@ -341,7 +341,7 @@ main (int argc, char *argv[]) {
if (do_codec_timing) {
srtp_policy_t policy;
int ignore;
@ -13,8 +13,8 @@ Unbreak build on mips64 arches.
crypto_policy_set_rtp_default(&policy.rtp);
crypto_policy_set_rtcp_default(&policy.rtcp);
@@ -323,33 +323,33 @@ main (int argc, char *argv[]) {
policy.key = test_key;
@@ -353,33 +353,33 @@ main (int argc, char *argv[]) {
policy.allow_repeat_tx = 0;
policy.next = NULL;
- printf("mips estimate: %e\n", mips);

View File

@ -1,8 +1,10 @@
@comment $OpenBSD: PLIST,v 1.2 2012/01/06 00:45:06 sthen Exp $
@comment $OpenBSD: PLIST,v 1.3 2015/04/25 23:40:49 sthen Exp $
include/srtp/
include/srtp/aes.h
include/srtp/aes_cbc.h
include/srtp/aes_gcm_ossl.h
include/srtp/aes_icm.h
include/srtp/aes_icm_ossl.h
include/srtp/alloc.h
include/srtp/auth.h
include/srtp/cipher.h
@ -13,6 +15,7 @@ include/srtp/crypto_math.h
include/srtp/crypto_types.h
include/srtp/cryptoalg.h
include/srtp/datatypes.h
include/srtp/ekt.h
include/srtp/err.h
include/srtp/getopt_s.h
include/srtp/gf2_8.h
@ -35,3 +38,4 @@ include/srtp/stat.h
include/srtp/ut_sim.h
include/srtp/xfm.h
lib/libsrtp.a
lib/pkgconfig/libsrtp.pc
--- test/rtpw_test.sh.orig Wed Mar 11 14:02:12 2015
+++ test/rtpw_test.sh Sat Apr 25 10:28:38 2015
@@ -45,13 +45,13 @@ key=Ky7cUDT2GnI0XKWYbXv9AYmqbcLsqzL9mvdN9t/G
-RTPW=rtpw
+RTPW=./rtpw
DEST_PORT=9999
DURATION=3
@@ -12,13 +12,13 @@ key=2b2edc5034f61a72345ca5986d7bfd0189aa6dc2ecab32fd9a
ARGS="-k $key -ae"
ARGS="-b $key -a -e 128"
# First, we run "killall" to get rid of all existing rtpw processes.
@ -21,8 +12,8 @@ $OpenBSD: patch-test_rtpw_test_sh,v 1.1 2012/01/06 00:45:06 sthen Exp $
# they are killed, those processes will linger. Re-running the script
# will get rid of them.
-killall rtpw 2&>/dev/null
+pkill rtpw 2&>/dev/null
-killall rtpw 2>/dev/null
+pkill rtpw 2>/dev/null
if test -x $RTPW; then

View File

@ -1,10 +1,10 @@
$OpenBSD: patch-test_srtp_driver_c,v 1.1 2012/05/09 16:29:23 jasper Exp $
$OpenBSD: patch-test_srtp_driver_c,v 1.2 2015/04/25 23:40:49 sthen Exp $
Unbreak build on mips64 arches.
@@ -12,13 +12,13 @@ key=2b2edc5034f61a72345ca5986d7bfd0189aa6dc2ecab32fd9a
ARGS="-k $key -ae"
ARGS="-b $key -a -e 128"
-# First, we run "killall" to get rid of all existing rtpw processes.
+# First, we run "pkill" to get rid of all existing rtpw processes.
# they are killed, those processes will linger. Re-running the script